@@ -1,10 +1,10 @@
 # -*- encoding: utf-8 -*-
 
 __title__ = 'pygithub3'
-__version__ = '0.5.1'
+__version__ = '0.6.2'
 __author__ = 'David Medina'
 __email__ = 'davidmedina9@gmail.com'
 __license__ = 'ISC'
 __copyright__ = 'Copyright 2012 David Medina'
 
-from github import Github
+from .github import Github
